@@ -5,6 +5,7 @@ import logging
 import os
 from typing import Union
 
+from .devices import DevicesApi
 from .groups import GroupsApi
 from .licenses import LicensesApi
 from .locations import LocationsApi
@@ -15,26 +16,26 @@ from .rest import RestSession
 from .telephony import TelephonyApi
 from .tokens import Tokens
 from .webhook import WebhookApi
+from .workspace_locations import WorkspaceLocationApi
 from .workspaces import WorkspacesApi
 from .workspace_settings import WorkspaceSettingsApi
 from dataclasses import dataclass
 
 __all__ = ['WebexSimpleApi']
 
-__version__ = '1.6.0'
+__version__ = '1.7.0'
 
 log = logging.getLogger(__name__)
 
 
-# TODO: devices
-
-
 @dataclass(init=False)
 class WebexSimpleApi:
     """
     The main API object
     """
 
+    #: devices API :class:`devices.DevicesApi`
+    devices: DevicesApi
     #: groups API :class:`groups.GroupsApi`
     groups: GroupsApi
     #: Licenses API :class:`licenses.LicensesApi`
@@ -53,6 +54,8 @@ class WebexSimpleApi:
     webhook: WebhookApi
     #: Workspaces API :class:`workspaces.WorkspacesApi`
     workspaces: WorkspacesApi
+    #: Workspace locations API; :class:`workspace_locations.WorkspaceLocationApi`
+    workspace_locations: WorkspaceLocationApi
     #: Workspace setting API :class:`workspace_settings.WorkspaceSettingsApi`
     workspace_settings: WorkspaceSettingsApi
     #: :class:`rest.RestSession` used for all API requests
@@ -76,6 +79,7 @@ class WebexSimpleApi:
             tokens = Tokens(access_token=tokens)
 
         session = RestSession(tokens=tokens, concurrent_requests=concurrent_requests)
+        self.devices = DevicesApi(session=session)
         self.groups = GroupsApi(session=session)
         self.licenses = LicensesApi(session=session)
         self.locations = LocationsApi(session=session)
@@ -85,6 +89,7 @@ class WebexSimpleApi:
         self.telephony = TelephonyApi(session=session)
         self.webhook = WebhookApi(session=session)
         self.workspaces = WorkspacesApi(session=session)
+        self.workspace_locations = WorkspaceLocationApi(session=session)
         self.workspace_settings = WorkspaceSettingsApi(session=session)
         self.session = session
 
