@@ -135,7 +135,11 @@ def dump_response(response: Response, file: TextIOBase = None, dump_log: logging
     for h in response.history:
         dump_response(response=h, file=output)
 
-    time_str = diff_ns is None and '' or f' ({diff_ns / 1000000.0:.3f} ms)'
+    if diff_ns is None:
+        time_str = ''
+    else:
+        time_str = f'({diff_ns / 1000000.0:.3f} ms)'
+
     print(f'Request {response.status_code}[{response.reason}]{time_str}: '
           f'{response.request.method} {response.request.url}', file=output)
 
@@ -173,6 +177,8 @@ def dump_response(response: Response, file: TextIOBase = None, dump_log: logging
             if 'access_token' in body:
                 # mask access token
                 body['access_token'] = '***'
+            elif 'refresh_token' in body:
+                body['refresh_token'] = '***'
             body = json.dumps(body, indent=2)
         except json.JSONDecodeError:
             pass
@@ -244,7 +250,7 @@ class RestSession(Session):
         return self._tokens.access_token
 
     @backoff.on_exception(backoff.constant, RestError, interval=0, giveup=_giveup_429)
-    def _request_w_response(self, method: str, url: str, headers=None,
+    def _request_w_response(self, method: str, url: str, headers=None, content_type: str = None,
                             **kwargs) -> Tuple[Response, StrOrDict]:
         """
         low level API REST request with support for 429 rate limiting
@@ -255,6 +261,8 @@ class RestSession(Session):
         :type url: str
         :param headers: prepared headers for request
         :type headers: Optional[dict]
+        :param content_type:
+        :type content_type: str
         :param kwargs: additional keyward args
         :type kwargs: dict
         :return: Tuple of response object and body. Body can be text or dict (parsed from JSON body)
@@ -265,6 +273,8 @@ class RestSession(Session):
                            'TrackingID': f'SIMPLE_{uuid.uuid4()}'}
         if headers:
             request_headers.update((k.lower(), v) for k, v in headers.items())
+        if content_type:
+            request_headers['content-type'] = content_type
         with self._sem:
             start = time.perf_counter_ns()
             response = self.request(method, url=url, headers=request_headers, **kwargs)
@@ -380,9 +390,9 @@ class RestSession(Session):
             model = model.parse_obj
 
         while url:
-            if url.startswith('https,'):
-                # TODO: this has to go as soon as WXCAPIBULK-27 gets fixed
-                url = url[6:]
+            # not needed any more, WXCAPIBULK-27 has been fixed
+            # if url.startswith('https,'):
+            #     url = url[6:]
             log.debug(f'{self}.pagination: getting {url}')
             response, data = self._request_w_response('GET', url=url, params=params, **kwargs)
             # params only in first request. In subsequent requests we rely on the completeness of the 'next' URL
@@ -392,6 +402,8 @@ class RestSession(Session):
                 url = str(response.links['next']['url'])
             except KeyError:
                 url = None
+            if not data:
+                continue
             # return all items
             if item_key is None:
                 if 'items' in data:
