@@ -22,9 +22,7 @@ class RouteGroup(ApiModel):
     # only returned in list() not in detail
     rg_id: Optional[str] = Field(alias='id')
     name: str
-    # TODO: doc defect not listed at https://developer.webex.com/docs/api/v1/webex-calling-organization-settings/read
-    #  -the-list-of-routing-groups
-    #: only returned by list() not as part of detail
+    #: only returned by list() not as part of detail()
     in_use: Optional[bool]
     #: only returned by detail()
     organization: Optional[Customer]
@@ -56,7 +54,7 @@ class RouteGroupApi(ApiChild, base='telephony/config/premisePstn/routeGroups'):
     API for everything route groups
     """
 
-    def list(self, *, name: str = None, order: str = None,
+    def list(self, name: str = None, order: str = None,
              org_id: str = None, **params) -> Generator[RouteGroup, None, None]:
         """
         List all Route Groups for an organization. A Route Group is a group of trunks that allows further scale and
@@ -79,7 +77,7 @@ class RouteGroupApi(ApiChild, base='telephony/config/premisePstn/routeGroups'):
         # noinspection PyTypeChecker
         return self.session.follow_pagination(url=url, params=params, model=RouteGroup)
 
-    def create(self, *, route_group: RouteGroup, org_id: str = None) -> str:
+    def create(self, route_group: RouteGroup, org_id: str = None) -> str:
         """
         Creates a Route Group for the organization.
 
@@ -105,8 +103,6 @@ class RouteGroupApi(ApiChild, base='telephony/config/premisePstn/routeGroups'):
         :return: id of new route group
         :rtype: str
         """
-        # TODO: doc defect. wrong URL at https://developer.webex.com/docs/api/v1/webex-calling-organization-settings
-        #  /create-route-group-for-a-organization
         params = org_id and {'orgId': org_id} or None
         body = route_group.json(include={'name': True,
                                          'local_gateways': {'__all__': {'trunk_id', 'priority'}}})
@@ -114,7 +110,7 @@ class RouteGroupApi(ApiChild, base='telephony/config/premisePstn/routeGroups'):
         data = self.post(url=url, params=params, data=body)
         return data['id']
 
-    def details(self, *, rg_id: str, org_id: str = None) -> RouteGroup:
+    def details(self, rg_id: str, org_id: str = None) -> RouteGroup:
         """
         Reads a Route Group for the organization based on id.
 
@@ -131,15 +127,12 @@ class RouteGroupApi(ApiChild, base='telephony/config/premisePstn/routeGroups'):
         :return: route group details
         :rtype: :class:`RouteGroup`
         """
-        # TODO: wrong data structure at
-        #  https://developer.webex.com/docs/api/v1/webex-calling-organization-settings/read-a-route-group-for-a
-        #  -organization
         params = org_id and {'orgId': org_id} or None
         url = self.ep(rg_id)
         data = self.get(url=url, params=params)
         return RouteGroup.parse_obj(data)
 
-    def update(self, *, rg_id: str, update: RouteGroup, org_id: str = None):
+    def update(self, rg_id: str, update: RouteGroup, org_id: str = None):
         """
         Modifies an existing Route Group for an organization based on id.
 
@@ -163,7 +156,7 @@ class RouteGroupApi(ApiChild, base='telephony/config/premisePstn/routeGroups'):
         data = self.post(url=url, params=params, data=body)
         self.put(url=url, params=params, data=data)
 
-    def delete_route_group(self, *, rg_id: str, org_id: str = None):
+    def delete_route_group(self, rg_id: str, org_id: str = None):
         """
         Remove a Route Group from an Organization based on id.
 
@@ -178,12 +171,11 @@ class RouteGroupApi(ApiChild, base='telephony/config/premisePstn/routeGroups'):
         :param org_id: Organization of the Route Group.
         :type org_id: str
         """
-        # TODO: doc defect. wrong URL
         params = org_id and {'orgId': org_id} or None
         url = self.ep(rg_id)
         self.delete(url=url, params=params)
 
-    def usage(self, *, rg_id: str, org_id: str = None) -> RouteGroupUsage:
+    def usage(self, rg_id: str, org_id: str = None) -> RouteGroupUsage:
         """
         List the number of "Call to" on-premises Extensions, Dial Plans, PSTN Connections, and Route Lists used by a
         specific Route Group. Users within Call to Extension locations are registered to a PBX which allows you to
